Crate plain_trie

Crate plain_trie 

Extendable classic retrieval tree implementation with fixed size alphabet per node.

Maps any T using any impl Iterator<Item = char> type.

Modules

english_letters
Module for working with English alphabet small letters, a-z.

Structs

Iter
Iterator for key-entry duos in tree.
IterMut
Mutable iterator for key-entry duos in tree.
Letter
Letter is Alphabet element, represents tree node.
Toter
Extracting iterator of key-entry duos of tree.
Trie
Trie implementation allowing for mapping any T to any impl Iterator<Item = char> type.

Enums

KeyErr
Key error enumeration.

Traits

InsResAide
Auxiliary trait for working with InsRes.
InsResAideEx
Extension trait to InsResAide trait.

Type Aliases

Alphabet
Tree node arms. Consists of Letters.
InsRes
Insert result type.
Ix
Index conversion function. Tighten with alphabet used. Returns corresponding usized index of char.
Re
Reversal index conversion function. Symmetrically mirrors Ix function.
Sight
‘Viewable’ key-entry duo type.
SightMut
‘Viewable’ mutable key-entry duo type.
Take
Key-entry duo type.